App

Struct App 

pub struct App {
    pub base: AppBase<ServerImpl<Details>>,
    pub attribute_types: Map<Type>,
    pub yivi: Option<YiviCtx>,
    pub auth_state_secret: SealingKey,
    pub auth_window: Duration,
    pub attr_key_secret: Vec<u8>,
    pub chained_sessions_ctl: Option<ChainedSessionsCtl>,
}
Authentication server per-thread App that handles incoming requests.

Fields

base: AppBase<ServerImpl<Details>>attribute_types: Map<Type>yivi: Option<YiviCtx>auth_state_secret: SealingKeyauth_window: Durationattr_key_secret: Vec<u8>chained_sessions_ctl: Option<ChainedSessionsCtl>

Implementations

Source

impl App

Implementaton of endpoints

pub async fn handle_auth_start( app: Rc<Self>, req: Json<AuthStartReq>, ) -> Result<AuthStartResp>

fn create_disclosure_con_for( &self, attr_type_id: &AttributeTypeIdentifier, ) -> Result<Vec<AttributeRequest>>

Creates a disclosure ‘conjunction’ for the given yivi attribute type identifier.

This is almost always just the attibute type idenfitier itself, unless we’re dealing with the pubhubs card - in which case two other factors are added that fixes the registration source, and allows the user to see the ‘comment’ attached to the card (usually the redacted email address and phone number.)

The yivi attribute type that will provide the actual value for the pubhubs attribute will always come first. This is important because yivi::SessionResult::validate_and_extract_raw_singles will only pick the first value from each inner conjunction.

async fn handle_auth_start_yivi( app: Rc<Self>, state: AuthState, yivi_chained_session: bool, yivi_chained_session_drip: bool, ) -> Result<AuthStartResp>

pub async fn handle_auth_complete( app: Rc<Self>, req: Json<AuthCompleteReq>, ) -> Result<AuthCompleteResp>

async fn handle_auth_complete_yivi( app: Rc<Self>, state: AuthState, disclosure: JWT, ) -> Result<AuthCompleteResp>

Source

impl App

pub(crate) fn registration_source<'a>(&'a self, yivi: &'a YiviCtx) -> &'a str

Gets the registration source to use when issuing a pubhubs card

pub(crate) fn issue_card( &self, card_pseud_package: CardPseudPackage, comment: Option<String>, ) -> Result<(ExtendedSessionRequest, Attr)>

Creates a yivi issuance request and pubhubs attribute for a PubHubs card

pub async fn handle_card(app: Rc<Self>, req: Json<CardReq>) -> Result<CardResp>

Implements api::auths::CardEP.

Source

impl App

pub async fn handle_attr_keys( app: Rc<Self>, reqs: Json<HashMap<Handle, AttrKeyReq>>, ) -> Result<AttrKeysResp>

Source

impl App

Helper functions

pub fn get_yivi(&self) -> Result<&YiviCtx, ErrorCode>

pub fn attr_type_from_handle<'s>( &'s self, attr_type_handle: &Handle, ) -> Option<&'s Type>

Get attr::Type by handle::Handle, returning None when it cannot be found.

Source

impl App

Source

impl App

Methods from Deref<Target = AppBase<ServerImpl<Details>>>

pub async fn get_object<T>( &self, id: &T::Identifier, ) -> Result<Option<(T, UpdateVersion)>>
where T: ObjectDetails,

Tries to retrieve an object of type T from this server’s object store with the given id, returning Ok(None) if no such object exists.

pub async fn put_object<T>( &self, obj: &T, update: Option<UpdateVersion>, ) -> Result<Option<UpdateVersion>>
where T: ObjectDetails,

Attempts to put an object of type T into the object store, only overwriting the object that is already present when the version of the to-be-overwritten object is passed via update.

Returs Ok(None) when there is already an object present in the store with that id and type, but its version was not specified in update.

pub async fn delete_object<T>(&self, id: T::Identifier) -> Result<bool>
where T: ObjectDetails,

Attempts to delete an object with the given Id; returns true when an object was deleted, and false when no object with the given id was found.

pub fn running_state_or_please_retry( &self, ) -> Result<&RunningState<S::ExtraRunningState>, ErrorCode>

Returns the current RunningState of this server when available. Otherwise returns api::ErrorCode::PleaseRetry.

pub fn running_state_or_internal_error( &self, ) -> Result<&RunningState<S::ExtraRunningState>, ErrorCode>

Returns the current RunningState of this server when available. Otherwise returns api::ErrorCode::InternalError.